@@ -94,7 +94,10 @@ class CfdeClient():
         logger.info("Initiating Native App Login...")
         logger.debug(f"Requesting Scopes: {self.scopes}")
         login_kwargs["requested_scopes"] = login_kwargs.get("requested_scopes", self.scopes)
-        self.__native_client.login(**login_kwargs)
+        try:
+            self.__native_client.login(**login_kwargs)
+        except fair_research_login.LoginException as le:
+            raise exc.NotLoggedIn(f"Unable to login: {str(le)}") from le
 
     def logout(self):
         """Log out and revoke this client's tokens. This object will no longer
@@ -376,8 +379,8 @@ class CfdeClient():
 
         return {
             "success": True,
-            "message": ("Started DERIVA ingest Flow\nFlow ID: {}\nFlow Instance ID: {}"
-                        .format(flow_id, flow_res["action_id"])),
+            "message": ("Started DERIVA ingest flow\nYour dataset has been "
+                        "submitted\nYou can check the progress with: cfde-submit status\n"),
             "flow_id": flow_id,
             "flow_instance_id": flow_res["action_id"],
             "cfde_dest_path": dest_path,
