@@ -4,7 +4,7 @@ import logging
 
 import click
 
-from cfde_submit import CfdeClient, exc
+from cfde_submit import CfdeClient, exc, version
 
 logger = logging.getLogger(__name__)
 DEFAULT_STATE_FILE = os.path.expanduser("~/.cfde_client.json")
@@ -96,10 +96,7 @@ def run(data_path, dcc_id, catalog, schema, output_dir, delete_dir, ignore_git,
         if verbose:
             print("Initializing Flow")
         cfde = CfdeClient()
-        if cfde.service_instance != "prod":
-            click.secho(f"Running on service '{cfde.service_instance}'", fg="yellow")
-        if not cfde.is_logged_in():
-            cfde.login()
+        login_user()
         if verbose:
             print("CfdeClient initialized, starting Flow")
         resp = input(f"Submit datapackage {os.path.basename(data_path)} using {dcc_id}? (y/N)? > ")
@@ -137,12 +134,6 @@ def run(data_path, dcc_id, catalog, schema, output_dir, delete_dir, ignore_git,
                 if verbose:
                     print("State saved to '{}'".format(client_state_file))
 
-                filename = os.path.basename(start_res["cfde_dest_path"])
-                print("\nThe BDBag with your data is named '{}', and will be available through "
-                      "Globus here:\n{}\n".format(filename, state["globus_web_link"]))
-                print("You BDBag will also be available via direct HTTP download here:\n{}"
-                      .format(state["http_link"]))
-
 
 @cli.command()
 @click.option("--flow-id", default=None, show_default=True)
@@ -151,6 +142,7 @@ def run(data_path, dcc_id, catalog, schema, output_dir, delete_dir, ignore_git,
 @click.option("--client-state-file", type=click.Path(exists=True), default=None)  # , hidden=True)
 def status(flow_id, flow_instance_id, raw, client_state_file):
     """Check the status of a Flow."""
+    login_user()
     if not flow_id or not flow_instance_id:
         if not client_state_file:
             client_state_file = DEFAULT_STATE_FILE
@@ -183,6 +175,26 @@ def status(flow_id, flow_instance_id, raw, client_state_file):
             print(status_res["clean_status"])
 
 
+def login_user(force_login=False, no_browser=False, no_local_server=False):
+    """
+    Arguments:
+        force_login -- Force a login flow with Globus Auth, even if tokens are valid
+        no_browser -- Disable automaically opening a browser for login
+        no_local_server -- Disable local server for automatically copying auth code
+    """
+    cfde = CfdeClient()
+    if cfde.service_instance != "prod":
+        click.secho(f"Running on service '{cfde.service_instance}'", fg="yellow")
+
+    try:
+        if not cfde.is_logged_in():
+            cfde.login(force=force_login, no_browser=no_browser, no_local_server=no_local_server)
+            click.secho("You are authenticated and your tokens have been cached.", fg='green')
+        cfde.check()
+    except exc.CfdeClientException as ce:
+        click.secho(str(ce), fg='red', err=True)
+
+
 @cli.command()
 @click.option("--force-login", is_flag=True, default=False, show_default=True)
 @click.option("--no_browser", is_flag=True, default=False)
@@ -191,18 +203,11 @@ def login(force_login, no_browser, no_local_server):
     """Perform the login step (which saves credentials) by initializing
     a CfdeClient. The Client is then discarded.
     """
-    cfde = CfdeClient()
-    if cfde.service_instance != "prod":
-        click.secho(f"Running on service '{cfde.service_instance}'", fg="yellow")
-    if cfde.is_logged_in():
+    logger.debug(f'Logged in? {CfdeClient().is_logged_in()}')
+    if CfdeClient().is_logged_in():
         click.secho("You are already logged in")
     else:
-        cfde.login(force=force_login, no_browser=no_browser, no_local_server=no_local_server)
-        click.secho("You are authenticated and your tokens have been cached.", fg='green')
-    try:
-        cfde.check()
-    except exc.CfdeClientException as ce:
-        click.secho(str(ce), fg='red')
+        login_user(force_login, no_browser, no_local_server)
 
 
 @cli.command()
@@ -214,3 +219,8 @@ def logout():
         click.secho("You have been logged out", fg='green')
     else:
         click.secho("You are not logged in")
+
+
+@cli.command(name='version')
+def version_cmd():
+    click.secho(version.__version__)
